@@ -178,6 +178,10 @@ func colorizeInstance(instance string) string {
 	return colorCallerPrefix.Sprint("i:") + colorInstance.Sprint(instance)
 }
 
+func colorizeRuntime(runtime string) string {
+	return colorCallerPrefix.Sprint("r:") + colorInstance.Sprint(runtime)
+}
+
 func LoggerBundle(ctx context.Context, bundle string) logr.Logger {
 	if !rootArgs.prettyLog {
 		return LoggerFrom(ctx, "bundle", bundle)
@@ -199,6 +203,13 @@ func LoggerBundleInstance(ctx context.Context, bundle, instance string) logr.Log
 	return LoggerFrom(ctx, "caller", fmt.Sprintf("%s %s %s", colorizeBundle(bundle), color.CyanString(">"), colorizeInstance(instance)))
 }
 
+func LoggerRuntime(ctx context.Context, runtime string) logr.Logger {
+	if !rootArgs.prettyLog {
+		return LoggerFrom(ctx, "runtime", runtime)
+	}
+	return LoggerFrom(ctx, "caller", colorizeRuntime(runtime))
+}
+
 // LoggerFrom returns a logr.Logger with predefined values from a context.Context.
 func LoggerFrom(ctx context.Context, keysAndValues ...interface{}) logr.Logger {
 	newLogger := logger
