@@ -131,6 +131,10 @@ func resetCmdArgs() {
 	bundleLintArgs = bundleLintFlags{}
 	bundleDelArgs = bundleDelFlags{}
 	bundleBuildArgs = bundleBuildFlags{}
+	vendorCrdArgs = vendorCrdFlags{}
+	vendorK8sArgs = vendorK8sFlags{}
+	pushArtifactArgs = pushArtifactFlags{}
+	pullArtifactArgs = pullArtifactFlags{}
 }
 
 func rnd(prefix string, n int) string {
