@@ -21,12 +21,11 @@ import (
 	"fmt"
 	"os"
 
-	oci "github.com/fluxcd/pkg/oci/client"
 	"github.com/spf13/cobra"
 
-	"github.com/stefanprodan/timoni/internal/engine"
+	apiv1 "github.com/stefanprodan/timoni/api/v1alpha1"
 	"github.com/stefanprodan/timoni/internal/flags"
-	"github.com/stefanprodan/timoni/internal/signutil"
+	"github.com/stefanprodan/timoni/internal/oci"
 )
 
 var pullModCmd = &cobra.Command{
@@ -35,13 +34,27 @@ var pullModCmd = &cobra.Command{
 	Long: `The pull command downloads the module from a container registry and
 extract its contents the specified directory.`,
 	Example: `  # Pull the latest stable version of a module
-  timoni mod pull oci://docker.io/org/app \
+  echo $DOCKER_TOKEN | timoni registry login docker.io -u timoni --password-stdin
+  timoni mod pull oci://docker.io/org/app-module \
 	--output ./path/to/module
 
   # Pull a specific module version from GitHub Container Registry
-  timoni mod pull oci://ghcr.io/org/manifests/app --version 1.0.0 \
-	--output ./path/to/module \
+  timoni mod pull oci://ghcr.io/org/modules/app --version 1.0.0 \
+	--output=./modules/app \
 	--creds timoni:$GITHUB_TOKEN
+
+  # Verify the Cosign signature and pull (the cosign binary must be present in PATH)
+  timoni mod pull oci://docker.io/org/app-module \
+	--output=./modules/app \
+	--verify=cosign \
+	--cosign-key=/path/to/cosign.pub
+
+  # Verify the Cosign keyless signature and pull (the cosign binary must be present in PATH)
+  timoni artifact pull oci://ghcr.io/org/modules/app \
+	--output=./modules/app \
+	--verify=cosign \
+	--certificate-identity-regexp="^https://github.com/org/.*$" \
+	--certificate-oidc-issuer=https://token.actions.githubusercontent.com \
 `,
 	RunE: pullCmdRun,
 }
@@ -93,14 +106,12 @@ func pullCmdRun(cmd *cobra.Command, args []string) error {
 	if len(args) < 1 {
 		return fmt.Errorf("module URL is required")
 	}
-	ociURL := args[0]
-
-	log := LoggerFrom(cmd.Context())
 
 	version := pullModArgs.version.String()
 	if version == "" {
-		version = engine.LatestTag
+		version = apiv1.LatestVersion
 	}
+	ociURL := fmt.Sprintf("%s:%s", args[0], version)
 
 	if pullModArgs.output == "" {
 		return fmt.Errorf("invalid output path %s", pullModArgs.output)
@@ -110,38 +121,36 @@ func pullCmdRun(cmd *cobra.Command, args []string) error {
 		return fmt.Errorf("invalid output path %s", pullModArgs.output)
 	}
 
-	url, err := oci.ParseArtifactURL(ociURL + ":" + version)
-	if err != nil {
-		return err
-	}
-
-	ctx, cancel := context.WithTimeout(context.Background(), rootArgs.timeout)
-	defer cancel()
-
-	ociClient := oci.NewClient(nil)
-
-	if pullModArgs.creds != "" {
-		if err := ociClient.LoginWithCredentials(pullModArgs.creds.String()); err != nil {
-			return fmt.Errorf("could not login with credentials: %w", err)
-		}
-	}
+	log := LoggerFrom(cmd.Context())
 
 	if pullModArgs.verify != "" {
-		err = signutil.Verify(log, pullModArgs.verify, url, pullModArgs.cosignKey, pullModArgs.certificateIdentity,
-			pullModArgs.certificateIdentityRegexp, pullModArgs.certificateOidcIssuer, pullModArgs.certificateOidcIssuerRegexp)
+		err := oci.VerifyArtifact(log,
+			pullModArgs.verify,
+			ociURL,
+			pullModArgs.cosignKey,
+			pullModArgs.certificateIdentity,
+			pullModArgs.certificateIdentityRegexp,
+			pullModArgs.certificateOidcIssuer,
+			pullModArgs.certificateOidcIssuerRegexp)
 		if err != nil {
 			return err
 		}
 	}
 
 	spin := StartSpinner("pulling module")
-	_, err = ociClient.Pull(ctx, url, pullModArgs.output)
-	spin.Stop()
+	defer spin.Stop()
+
+	ctx, cancel := context.WithTimeout(context.Background(), rootArgs.timeout)
+	defer cancel()
+
+	opts := oci.Options(ctx, pullModArgs.creds.String())
+	err := oci.PullArtifact(ociURL, pullModArgs.output, apiv1.AnyContentType, opts)
 	if err != nil {
 		return err
 	}
 
-	log.Info(fmt.Sprintf("module extracted to %s", pullModArgs.output))
+	spin.Stop()
+	log.Info(fmt.Sprintf("extracted: %s", colorizeSubject(pullModArgs.output)))
 
 	return nil
 }
